================
For developpers
================

additional python packages required
===================================

- sphinx
    to generate .html file from .rst file

- cx_freeze, pywin32
    to generate w32 standalone package

